langtools/src/jdk.compiler/share/classes/com/sun/source/util/DocTreeFactory.java
changeset 41452 ddaef4bba083
parent 37009 476d8d615222
child 42831 feff6f296019
--- a/langtools/src/jdk.compiler/share/classes/com/sun/source/util/DocTreeFactory.java	Mon Oct 10 06:47:47 2016 -0700
+++ b/langtools/src/jdk.compiler/share/classes/com/sun/source/util/DocTreeFactory.java	Mon Oct 10 11:21:00 2016 -0700
@@ -112,12 +112,11 @@
 
     /**
      * Create a new {@code DocCommentTree} object, to represent a complete doc comment.
      * @param firstSentence the first sentence of the doc comment
      * @param body the body of the doc comment following the first sentence
      * @param tags the block tags in the doc comment
      * @return a {@code DocCommentTree} object
      */
-    DocCommentTree newDocCommentTree(List<? extends DocTree> firstSentence, List<? extends DocTree> body, List<? extends DocTree> tags);
+    DocCommentTree newDocCommentTree(List<? extends DocTree> fullBody, List<? extends DocTree> tags);
 
     /**
      * Create a new {@code DocRootTree} object, to represent an {@code {@docroot} } tag.
@@ -112,12 +112,11 @@
     /**
      * Create a new {@code DocCommentTree} object, to represent a complete doc comment.
-     * @param firstSentence the first sentence of the doc comment
-     * @param body the body of the doc comment following the first sentence
+     * @param fullBody the entire body of the doc comment
      * @param tags the block tags in the doc comment
      * @return a {@code DocCommentTree} object